Enum DbInstance

pub enum DbInstance {
    Mem(Db<MemStorage>),
    Sqlite(Db<SqliteStorage>),
}
A dispatcher for concrete storage implementations, wrapping Db. This is done so that client code does not have to deal with generic code constantly. You may prefer to use Db directly, especially if you provide a custom storage engine.

Many methods are dispatching methods for the corresponding methods on Db.

Other methods are wrappers simplifying signatures to deal with only strings. These methods made code for interop with other languages much easier, but are not desirable if you are using Rust.

Variants



Mem(Db<MemStorage>)

In memory storage (not persistent)



Sqlite(Db<SqliteStorage>)

Sqlite storage

Implementations

Source

impl DbInstance

pub fn new(engine: &str, path: impl AsRef<Path>, options: &str) -> Result<Self>

Create a DbInstance, which is a dispatcher for various concrete implementations. The valid engines are:

  • mem
  • sqlite
  • rocksdb
  • newrocksdb
  • sled
  • tikv

assuming all features are enabled during compilation. Otherwise only some of the engines are available. The mem engine is always available.

path is ignored for mem and tikv engines. options is ignored for every engine except tikv.

pub fn new_with_str( engine: &str, path: &str, options: &str, ) -> Result<Self, String>

Same as Self::new, but inputs and error messages are all in strings

pub fn get_fixed_rules(&self) -> BTreeMap<String, Arc<Box<dyn FixedRule>>>

Dispatcher method. See crate::Db::get_fixed_rules.

pub fn run_script( &self, payload: &str, params: BTreeMap<String, DataValue>, mutability: ScriptMutability, ) -> Result<NamedRows>

Dispatcher method. See crate::Db::run_script.

pub fn run_default(&self, payload: &str) -> Result<NamedRows>

run_script with mutable script and no parameters

pub fn run_script_ast( &self, payload: CozoScript, cur_vld: ValidityTs, mutability: ScriptMutability, ) -> Result<NamedRows>

Run a parsed (AST) program. If you have a string script, use run_script or run_default.

pub fn run_script_fold_err( &self, payload: &str, params: BTreeMap<String, DataValue>, mutability: ScriptMutability, ) -> JsonValue

Run the CozoScript passed in. The params argument is a map of parameters. Fold any error into the return JSON itself. See crate::Db::run_script.

pub fn run_script_str( &self, payload: &str, params: &str, immutable: bool, ) -> String

Run the CozoScript passed in. The params argument is a map of parameters formatted as JSON. See crate::Db::run_script.

pub fn export_relations<I, T>( &self, relations: I, ) -> Result<BTreeMap<String, NamedRows>>
where T: AsRef<str>, I: Iterator<Item = T>,

Dispatcher method. See crate::Db::export_relations.

pub fn export_relations_str(&self, data: &str) -> String

Export relations to JSON-encoded string. See crate::Db::export_relations

pub fn import_relations(&self, data: BTreeMap<String, NamedRows>) -> Result<()>

Dispatcher method. See crate::Db::import_relations.

pub fn import_relations_str(&self, data: &str) -> String

Import a relation, the data is given as a JSON string, and the returned result is converted into a string. See crate::Db::import_relations.

pub fn import_relations_str_with_err(&self, data: &str) -> Result<()>

Import a relation, the data is given as a JSON string. See crate::Db::import_relations.

pub fn backup_db(&self, out_file: impl AsRef<Path>) -> Result<()>

Dispatcher method. See crate::Db::backup_db.

pub fn backup_db_str(&self, out_file: impl AsRef<Path>) -> String

Backup the running database into an Sqlite file, with JSON string return value. See crate::Db::backup_db.

pub fn restore_backup(&self, in_file: impl AsRef<Path>) -> Result<()>

Dispatcher method. See crate::Db::restore_backup.

pub fn restore_backup_str(&self, in_file: impl AsRef<Path>) -> String

Restore from an Sqlite backup, with JSON string return value. See crate::Db::restore_backup.

pub fn import_from_backup( &self, in_file: impl AsRef<Path>, relations: &[String], ) -> Result<()>

Dispatcher method. See crate::Db::import_from_backup.

pub fn import_from_backup_str(&self, payload: &str) -> String

Import relations from an Sqlite backup, with JSON string return value. See crate::Db::import_from_backup.

pub fn register_callback( &self, relation: &str, capacity: Option<usize>, ) -> (u32, Receiver<(CallbackOp, NamedRows, NamedRows)>)

Dispatcher method. See crate::Db::register_callback.

pub fn unregister_callback(&self, id: u32) -> bool

Dispatcher method. See crate::Db::unregister_callback.

pub fn register_fixed_rule<R>(&self, name: String, rule_impl: R) -> Result<()>
where R: FixedRule + 'static,

Dispatcher method. See crate::Db::register_fixed_rule.

pub fn unregister_fixed_rule(&self, name: &str) -> Result<bool>

Dispatcher method. See crate::Db::unregister_fixed_rule

pub fn run_multi_transaction( &self, write: bool, payloads: Receiver<TransactionPayload>, results: Sender<Result<NamedRows>>, )

Dispatcher method. See crate::Db::run_multi_transaction

pub fn multi_transaction(&self, write: bool) -> MultiTransaction

A higher-level, blocking wrapper for crate::Db::run_multi_transaction. Runs the transaction on a dedicated thread. Write transactions may block other reads, but we guarantee that this does not happen for the RocksDB backend.