Module parse

AST for Cozo scripts, for generating Cozo scripts programmatically.

NOTE! This is unstable, the AST structure and method signatures may change in any release. Use at your own risk.

Structs

ImperativeStmtClause
ImperativeSysop
SourceSpan
Span of the element in the source script, with starting and ending positions.

Enums

CozoScript
This represents a full Cozo script, as you’d pass to run_script.
ImperativeStmt
Rule

Functions

parse_script
This parses a text script into the AST used by Cozo.

Type Aliases

ImperativeProgram
This is a chained query, a series of {} queries possibly with imperative directives like %if and %loop.