pub struct FixedRuleInputRelation<'a, 'b> { /* private fields */ }Expand description
Represents an input relation during the execution of a fixed rule
Implementations
Sourceimpl<'a, 'b> FixedRuleInputRelation<'a, 'b>
impl<'a, 'b> FixedRuleInputRelation<'a, 'b>
Sourcepub fn ensure_min_len(self, len: usize) -> Result<Self>
pub fn ensure_min_len(self, len: usize) -> Result<Self>
Ensure the input relation contains tuples of the given minimal length.
Sourcepub fn get_binding_map(&self, offset: usize) -> BTreeMap<Symbol, usize>
pub fn get_binding_map(&self, offset: usize) -> BTreeMap<Symbol, usize>
Get the binding map of the input relation
Sourcepub fn iter(
&self,
) -> Result<Box<dyn Iterator<Item = Result<Vec<DataValue>>> + 'a>>
pub fn iter( &self, ) -> Result<Box<dyn Iterator<Item = Result<Vec<DataValue>>> + 'a>>
Iterate the input relation
Sourcepub fn prefix_iter(
&self,
prefix: &DataValue,
) -> Result<Box<dyn Iterator<Item = Result<Vec<DataValue>>> + '_>>
pub fn prefix_iter( &self, prefix: &DataValue, ) -> Result<Box<dyn Iterator<Item = Result<Vec<DataValue>>> + '_>>
Iterate the relation with the given single-value prefix
Sourcepub fn span(&self) -> SourceSpan
pub fn span(&self) -> SourceSpan
Get the source span of the input relation. Useful for generating informative error messages.
Sourcepub fn as_directed_graph(
&self,
undirected: bool,
) -> Result<(DirectedCsrGraph<u32>, Vec<DataValue>, BTreeMap<DataValue, u32>)>
pub fn as_directed_graph( &self, undirected: bool, ) -> Result<(DirectedCsrGraph<u32>, Vec<DataValue>, BTreeMap<DataValue, u32>)>
Convert the input relation into a directed graph.
If undirected is true, then each edge in the input relation is treated as a pair
of edges, one for each direction.
Returns the graph, the vertices in a vector with the index the same as used in the graph, and the inverse vertex mapping.
Sourcepub fn as_directed_weighted_graph(
&self,
undirected: bool,
allow_negative_weights: bool,
) -> Result<(DirectedCsrGraph<u32, (), f32>, Vec<DataValue>, BTreeMap<DataValue, u32>)>
pub fn as_directed_weighted_graph( &self, undirected: bool, allow_negative_weights: bool, ) -> Result<(DirectedCsrGraph<u32, (), f32>, Vec<DataValue>, BTreeMap<DataValue, u32>)>
Convert the input relation into a directed weighted graph.
If undirected is true, then each edge in the input relation is treated as a pair
of edges, one for each direction.
Returns the graph, the vertices in a vector with the index the same as used in the graph, and the inverse vertex mapping.